@@ -3,7 +3,7 @@ DictInventory plugin
 ####################
 
 DictInventory is an inventory plugin that loads data from Python dictionaries.
-  
+
 DictInventory sample usage
 ==========================
 
@@ -11,7 +11,7 @@ Need to instruct Nornir to use DictInventory plugin on instantiation::
 
     import yaml
     from nornir import InitNornir
-    
+
     inventory_data = '''
     hosts:
       R1:
@@ -26,15 +26,15 @@ Need to instruct Nornir to use DictInventory plugin on instantiation::
         hostname: 192.168.1.154
         platform: ios
         groups: [lab]
-    
+
     groups:
       lab:
         username: cisco
         password: cisco
     '''
-    
+
     inventory_dict = yaml.safe_load(inventory_data)
-    
+
     NornirObj = InitNornir(
         inventory={
             "plugin": "DictInventory",
@@ -57,9 +57,7 @@ from typing import Any, Dict, Type
 from nornir.core.inventory import (
     Inventory,
     Group,
-    Groups,
     Host,
-    Hosts,
     Defaults,
     ConnectionOptions,
     HostOrGroup,
@@ -124,6 +122,7 @@ class DictInventory:
     :param groups: dictionary with groups data
     :param defaults: dictionary with defaults data
     """
+
     def __init__(self, hosts: Dict, groups: Dict, defaults: Dict) -> None:
         self.hosts = hosts
         self.groups = groups
@@ -145,5 +144,5 @@ class DictInventory:
         for h in nr_hosts.values():
             h.groups = ParentGroups([nr_groups[g] for g in h.groups])
         for g in nr_groups.values():
-            g.groups = ParentGroups([groups[g] for g in g.groups])
+            g.groups = ParentGroups([nr_groups[g] for g in g.groups])
         return Inventory(hosts=nr_hosts, groups=nr_groups, defaults=nr_defaults)
